import { min, max, quantile, mean } from 'd3';

export const BoxPlot = ({
  data,
  xScale,
  xValue,
  rectWidth = 50,
  showMean = true,
  color = "steelblue"
}) => {
  const xArray = data.map(xValue);
  const xMin = min(xArray);
  const xMax = max(xArray);
  const xQ1 = quantile(xArray, 0.25);
  const xQ3 = quantile(xArray, 0.75);

  return (
    <g>
      <line
        x1={xScale(xMin)}
        x2={xScale(xQ1)}
        stroke={color}
        strokeWidth={3}
      />
      <line
        x1={xScale(xQ3)}
        x2={xScale(xMax)}
        stroke={color}
        strokeWidth={3}
      />
      <rect
        x={xScale(xQ1)}
        y={-rectWidth / 2}
        width={xScale(xQ3) - xScale(xQ1)}
        height={rectWidth}
        fill="none"
        stroke={color}
        strokeWidth="3"
        rx="3"
      />
      <line
        y1={-rectWidth / 2}
        y2={rectWidth / 2}
        transform={`translate(${xScale(
          quantile(xArray, 0.5)
        )},0)`}
        stroke={color}
        strokeWidth={3}
      />
      {showMean ? (
        <line
          y1={-rectWidth / 2}
          y2={rectWidth / 2}
          transform={`translate(${xScale(
            mean(xArray)
          )},0)`}
          stroke="#E34234"
          strokeWidth={3}
          strokeDasharray="8 6"
        />
      ) : null}
    </g>
  );
};
