import React from 'react';
import ReactDOM from 'react-dom';
import { scaleLinear, extent, min, max } from 'd3';
import { VizContainer } from './VizContainer';
import { useData } from './useData';
import { BoxPlot } from './BoxPlot';
import { AxisBottom } from './AxisBottom';

const width = 960;
const height = 500;
const margin = {
  top: 100,
  right: 60,
  bottom: 100,
  left: 30,
};
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const xValue = (d) => d.age;
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth]);

  return (
    <VizContainer
      width={width}
      height={height}
      margin={margin}
      innerWidth={innerWidth}
      innerHeight={innerHeight}
    >
      <AxisBottom
        xScale={xScale}
        innerWidth={innerWidth}
        innerHeight={innerHeight}
      />
      <g transform="translate(0,150)">
        <BoxPlot
          data={data}
          xScale={xScale}
          xValue={xValue}
          color="#0B1F65"
        />
      </g>
    </VizContainer>
  );
};

ReactDOM.render(<App />, document.getElementById('root'));
